// SINGLE PEAKS (c1 = height, c2 = mean, c3 = FWHM, c4 = other parameter)
// c1 is always replaced by abs(c1) in evaluating these peak functions

gs(x,c1,c2,c3)          // gaussian
lz(x,c1,c2,c3)          // lorentzian
gl(x,c1,c2,c3,c4)       // gaussian-lorentzian mix, in proportion G:L = c4:1-c4
vt(x,c1,c2,c3,c4)       // Voigt = lorentz(x,c1,c2,c3) X gauss(x,c1,c2,c4)
ag(x,c1,c2,c3,c4)       // Asymmetric gaussian: c4 = asymmetry
ds(x,c1,c2,c3,c4)       // Doniach-Sunjic: c4 = asymmetry
c1 - c3*(c2 - x)**2     // quadratic to locate peak maximum

// DOUBLE PEAKS
gs(x,c1,c2,c3) + gs(x,c4,c5,c6)           // gaussian
lz(x,c1,c2,c3) + lz(x,c4,c5,c6)           // lorentzian
gl(x,c1,c2,c3,c7) + gl(x,c4,c5,c6,c7)     // gaussian-lorentzian mix
vt(x,c1,c2,c3,c7) + vt(x,c4,c5,c6,c7)     // Voigt (same broadening)
ag(x,c1,c2,c3,c7) + ag(x,c4,c5,c6,c8)     // asymmetric gaussian
ds(x,c1,c2,c3,c7) + ds(x,c4,c5,c6,c8)     // Doniach-Sunjic

// TRIPLE PEAKS
gs(x,c1,c2,c3) + gs(x,c4,c5,c6) + gs(x,c7,c8,c9)         // gaussian
lz(x,c1,c2,c3) + lz(x,c4,c5,c6) + lz(x,c7,c8,c9)         // lorentzian
gl(x,c1,c2,c3,c10)+gl(x,c4,c5,c6,c10)+gl(x,c7,c8,c9,c10) // gauss-lorentz mixtures
vt(x,c1,c2,c3,c10)+vt(x,c4,c5,c6,c10)+vt(x,c4,c5,c6,c10) // Voigt
ag(x,c1,c2,c3,c10)+ag(x,c4,c5,c6,c11)+ag(x,c7,c8,c9,c12) // asymmetric gaussian
ds(x,c1,c2,c3,c10)+ds(x,c4,c5,c6,c11)+ds(x,c7,c8,c9,c12) // Doniach-Sunjic

// CONSTRAINED GAUSSIAN DOUBLETS  (dx = c4, I1:I2 = 1:c5)
gsd(x,c1,c2,c3,c4,c5) // 1 gaussian doublet
gsd(x,c1,c2,c3,c4,c5)+gsd(x,c6,c7,c3,c4,c5) // 2 gaussian doublets
gsd(x,c1,c2,c3,c4,c5)+gsd(x,c6,c7,c3,c4,c5)+gsd(x,c8,c9,c3,c4,c5) // 3 gaussian doublets

// CONSTRAINED LORENTZIAN DOUBLETS  (dx = c4, I1:I2 = 1:c5)
lzd(x,c1,c2,c3,c4,c5) // 1 lorentzian doublet
lzd(x,c1,c2,c3,c4,c5)+lzd(x,c6,c7,c3,c4,c5) // 2 lorentzian doublets
lzd(x,c1,c2,c3,c4,c5)+lzd(x,c6,c7,c3,c4,c5)+lzd(x,c8,c9,c3,c4,c5) // 3 lorentzian doublets

// CONSTRAINED VOIGT DOUBLETS  (dx = c5, I1:I2 = 1:c6)
vtd(x,c1,c2,c3,c4,c5,c6) // 1 Voigt doublet
vtd(x,c1,c2,c3,c4,c5,c6)+vtd(x,c7,c8,c3,c4,c5,c6) // 2 Voigt doublets
vtd(x,c1,c2,c3,c4,c5,c6)+vtd(x,c7,c8,c3,c4,c5,c6)+vtd(x,c9,c10,c3,c4,c5,c6) // 3 Voigt doublets

// CONSTRAINED GAUSS-LORENTZ MIX DOUBLETS  (G:L = c4:1-c4, dx = c5, I1:I2 = 1:c6)
gld(x,c1,c2,c3,c4,c5,c6) // 1 G+L doublet
gld(x,c1,c2,c3,c4,c5,c6)+gld(x,c7,c8,c3,c4,c5,c6) // 2 G+L doublets
gld(x,c1,c2,c3,c4,c5,c6)+gld(x,c7,c8,c3,c4,c5,c6)+gld(x,c9,c10,c3,c4,c5,c6) // 3 G+L doublets

// CONSTRAINED DONIACH-SUNJIC DOUBLETS  (asymm = c4, dx = c5, I1:I2 = 1:c6)
dsd(x,c1,c2,c3,c4,c5,c6) // 1 DS doublet
dsd(x,c1,c2,c3,c4,c5,c6)+dsd(x,c7,c8,c3,c4,c5,c6) // 2 DS doublets
dsd(x,c1,c2,c3,c4,c5,c6)+dsd(x,c7,c8,c3,c4,c5,c6)+dsd(x,c9,c10,c3,c4,c5,c6) // 3 DS doublets

// GENERAL FUNCTIONS
c1*exp(-c2*x)                                  // exponential decay
c1 + c2*ln(x)                                  // log form of power law
c1*x**c2                                       // power law
c1 + c2*x                                      // linear
c1 + c2*x + c3*x**2                            // quadratic
c1 + c2*x + c3*x**2 + c4*x**3                  // cubic
c1 + c2*x + c3*x**2  + c4*x**3 + c5*x**4       // quartic
c1*((exp(-c3*(x-c2))) **2- 2*exp(-c3*(x-c2)))  // Morse potential function

